@@ -236,6 +236,7 @@ GSM_Error GSM_Device_Bluetooth::Connect(char *address, int channel)
 bool GSM_Device_Bluetooth::CheckServiceName(char *service, char *Prot)
 {
         if (!strcmp(Prot,"bluephonet") && strstr(service,"Nokia PC Suite")!=NULL) return true;
+        if (!strcmp(Prot,"blueat") && strstr(service,"COM")!=NULL) return true;
 
 	return false;
 }
@@ -364,7 +365,7 @@ GSM_Error GSM_Device_Bluetooth::Open(char *Dev, char *Prot, char *Pho, char **De
 
 	(*Debug)->Deb("[DEVICE    : opening device blue\n");
 
-	if (!strcmp(Prot,"bluephonet")) {
+	if (!strcmp(Prot,"bluephonet") || !strcmp(Prot,"blueat")) {
 #ifdef BLUETOOTH_RF_SEARCHING
 		error = Sock->Init(Debug);
 		if (error.Code != GSM_ERR_NONE) return error;
