@@ -464,6 +464,13 @@ bool GSM_Phone::Ans(char *MsgTyp, int SubTypeChar, unsigned char SubType, int Re
 
 	/* AT commands */
 	if (strlen((const char *)MsgType) > 2) {
+		if (strstr((const char *)(*Protocols)->Current->MsgReceived.Buffer.data(),(const char *)MsgType)!=NULL) {
+			(AS->FrameFound) = true;
+			if (Request != ID_IncomingFrame && Request != AS->RequestID) return false;
+			return true;
+		} else {
+			return false;
+		}
 	}
 
 	/* ------------ Nokia and other binary stuff ------------------ */
