@@ -24,6 +24,7 @@ if(Ans("\x03",0x03,0x04,ID_GetPBKStatus+ID,&AS))	return ReplyGetPBKStatus		(msg,
 if(Ans("\x03",0x03,0x08,ID_GetPBK+ID, &AS))	     	return ReplyGetPBK		      	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x0C,ID_SetPBK+ID, &AS))	     	return DCT34->ReplySetPBK	       	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x10,ID_DelPBK+ID, &AS))	     	return DCT34->ReplyDelPBK	       	(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x03",0x03,0x26,ID_GetPBK+ID3, &AS))     	return ReplyGetPBKFeatures 		(msg,Debug,(unsigned char *)Struct);
 
 if(Ans("\x13",0x03,0x02,ID_AddCalendar+ID3,&AS))	return DCT34->ReplyAddCalendar1	 	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x04,ID_AddCalendar+ID3,&AS))	return DCT34->ReplyAddCalendar1	 	(msg,Debug,(unsigned char *)Struct);
@@ -122,6 +123,8 @@ GSM_Error GSM_Phone_N7110::ReplyGetPBK(GSM_Protocol_Message *msg, DebugInfo **De
 	GSM_PBKEntry *Entry = (GSM_PBKEntry *)S;
 
 	if (msg->Buffer.data()[6] == 0x0F) {
+		return GSM_Return_Error(GSM_ERR_EMPTY);
+
 		(*Debug)->Deb("RECEIVED: error %i receiving PBK entry\n",0);
 		return GSM_Return_Error(GSM_ERR_UNKNOWN);
 	}
@@ -161,6 +164,12 @@ GSM_Error GSM_Phone_N7110::SetPBK(GSM_PBKEntry *Entry)
 		0x00, 0x00,	     // location
 		0x00, 0x00, 0x00};
 
+	if (Entry->Memory == MEM_PHONE && PhonePBKFeatures.Types.size() == 0) {
+		PhonePBKFeatures.Memory = MEM_PHONE;
+		error = DCT34->GetPBKFeatures(&PhonePBKFeatures);
+		if (error.Code != GSM_ERR_NONE) return error;
+	}
+
 	Buff[11] = DCT34->Get7110DCT4MemoryType(Entry->Memory);
 	if (Buff[11] == 0x00) return GSM_Return_Error(GSM_ERR_UNKNOWN);
 
@@ -168,15 +177,32 @@ GSM_Error GSM_Phone_N7110::SetPBK(GSM_PBKEntry *Entry)
 	Buff[12] = Entry->Location / 256;
 	Buff[13] = Entry->Location % 256;
 
-	error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, NULL);
-	if (error.Code != GSM_ERR_NONE) return error;
+	while (true) {
+		if (Entry->Memory == MEM_PHONE) {
+			error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, &PhonePBKFeatures);
+		} else {
+			error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, NULL);
+		}
+		if (error.Code != GSM_ERR_NONE) return error;
 
-	Buffer2.append((const unsigned char*)Buff,sizeof(Buff));
-	Buffer2.push_back(Number);
-	Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
+		Buffer2.append((const unsigned char*)Buff,sizeof(Buff));
+		Buffer2.push_back(Number);
+		Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
 
-	(*Debug)->Deb("SENT: setting entry %i in memory %s\n",Entry->Location,GSM_GetMemoryName(Entry->Memory));
-	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x03, 4, ID_SetPBK+ID, Entry);
+		(*Debug)->Deb("SENT: setting entry %i in memory %s\n",Entry->Location,GSM_GetMemoryName(Entry->Memory));
+		error = Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x03, 4, ID_SetPBK+ID, Entry);
+		if (error.Code == GSM_ERR_TOO_MANY_ENTRIES) {
+			Buffer.clear();
+			Buffer2.clear();
+			Number--;
+			continue;
+		}
+		if (error.Code == GSM_ERR_FILE_EXIST) {
+			error.Code = GSM_ERR_NONE;
+		}
+
+		return error;
+	}
 }
 
 GSM_Error GSM_Phone_N7110::DeletePBK(GSM_PBKEntry *Entry)
@@ -213,7 +239,11 @@ GSM_Error GSM_Phone_N7110::AddCalendar(GSM_CalendarEntry *Entry)
 	GSM_Calendar_Type       Type = Entry->Type;
 	GSM_Error	       error;
 
-	if (Type == Calendar_Type_Reminder) Entry->Type = Calendar_Type_Meeting;
+	Entry->TypeSetError = GSM_Return_Error(GSM_ERR_NONE);
+	if (Type == Calendar_Type_Reminder) {
+		Entry->Type = Calendar_Type_Meeting;
+		Entry->TypeSetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+	}
 	error = DCT34->AddCalendar1(Entry);
 	Entry->Type = Type;
 	return error;
@@ -354,7 +384,7 @@ GSM_Error GSM_Phone_N7110::GetSMS(GSM_SMSList *List, wchart SMS_ID)
 	error = Write(Buff, 7, 0x14, 4, ID_GetSMS+ID, List);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
-	List->Folder = FolderID;
+	List->Folder = FolderID/8;
 	SubEntry = NULL;
 	while (List->GetNext(&SubEntry) == TRUE) {
 		SubEntry->GetSMS()->Memory  = MEM_PHONE;
@@ -373,6 +403,31 @@ GSM_Error GSM_Phone_N7110::GetSMS(GSM_SMSList *List, wchart SMS_ID)
 	return error;
 }
 
+GSM_Error GSM_Phone_N7110::GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSEntry *MMS, int *Current, int *MaxInFolder)
+{
+	GSM_Error	error;
+	wchart		SMSID;
+
+	if (start == TRUE) {
+		SMSLocations.Locations.clear();
+		SMSLocations.FolderID = atoi(UnicodeToStringReturn(SMSFolder->ID.data()));
+		error = GetSMSFolderStatus(&SMSLocations);
+		if (error.Code != GSM_ERR_NONE) return error;
+
+		SMSLocation = 0;
+	}
+
+	if (SMSLocation == SMSLocations.Locations.length()) return GSM_Return_Error(GSM_ERR_EMPTY);
+
+	SetSMSLocation(&SMSID, atoi(UnicodeToStringReturn(SMSFolder->ID.data())),SMSLocations.Locations.data()[SMSLocation]);
+
+	SMSLocation++;
+	MMS->Folder     = 0;
+	*Current 	= SMSLocation;
+	*MaxInFolder	= SMSLocations.Locations.length();
+	return GetSMS(SMS,SMSID);
+}
+
 GSM_Error GSM_Phone_N7110::ReplyGetSMSFolders(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
 	GSM_SMSMMSFolders	*Folders = (GSM_SMSMMSFolders *)S;
@@ -394,12 +449,12 @@ GSM_Error GSM_Phone_N7110::ReplyGetSMSFolders(GSM_Protocol_Message *msg, DebugIn
 	Memory = MEM_SIM_PHONE;
 	for (i=0;i<msg->Buffer.data()[4];i++) {
 		current++;
-		Inbox = false;
 		if (i > 1) Memory = MEM_PHONE;
-		sprintf(buff,"%i",i);
+		sprintf(buff,"%i",(i+1)*8);
 		ID.clear();
 		ID.append(StringToUnicodeReturn(buff));
 		Folders->Add(NokiaGetUnicodeString(msg->Buffer.data()+current),FALSE,Inbox,FALSE,Memory,&ID,i+1,-1);
+		Inbox = false;
 		while (true) {
 			current+=2;
 			if (msg->Buffer.data()[current] == 0 && msg->Buffer.data()[current+1] == 0) break;
@@ -409,6 +464,14 @@ GSM_Error GSM_Phone_N7110::ReplyGetSMSFolders(GSM_Protocol_Message *msg, DebugIn
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
+GSM_Error GSM_Phone_N7110::GetSMSMMSFolders(GSM_SMSMMSFolders *Folders)
+{
+	unsigned char Buff[] = {NOKIA_FRAME1, 0x7A, 0x00, 0x00};
+
+	(*Debug)->Deb("SENT: getting SMS folders\n");
+	return Write(Buff, sizeof(Buff), 0x14, 4, ID_GetSMSFolders+ID, Folders);
+}
+
 GSM_Error GSM_Phone_N7110::GetSMSC(GSM_SMSC *SMSC)
 {
 	return DCT3->GetSMSC(SMSC);
@@ -643,3 +706,27 @@ GSM_Error GSM_Phone_N7110::DeleteSMS(GSM_SMSList *List)
 	(*Debug)->Deb("SENT: deleting SMS\n");
 	return Write((unsigned char *)Buffer.data(), Buffer.size(), 0x14, 4, ID_DelSMS+ID,List);
 }
+
+GSM_Error GSM_Phone_N7110::ReplyGetPBKFeatures(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_PBK_Features *Entry = (GSM_PBK_Features *)S;
+	int 		 i,pos=6;
+
+	(*Debug)->Deb("  Features: ");
+	Entry->Types.clear();
+	for (i=0;i<msg->Buffer.data()[5];i++) {
+		(*Debug)->Deb("%02x ",msg->Buffer.data()[pos+4]);
+		Entry->Types.push_back(msg->Buffer.data()[pos+4]);
+		pos+=msg->Buffer.data()[pos+3];
+	}
+	(*Debug)->Deb("\n");
+
+	Entry->Numbers.clear();
+	Entry->Numbers.push_back(NPBK_NUMBER_HOME);
+	Entry->Numbers.push_back(NPBK_NUMBER_MOBILE);
+	Entry->Numbers.push_back(NPBK_NUMBER_FAX);
+	Entry->Numbers.push_back(NPBK_NUMBER_WORK);
+	Entry->Numbers.push_back(NPBK_NUMBER_GENERAL);
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
