@@ -113,16 +113,16 @@ GSM_Error GSM_Phone_N6510::AddFolder1(FileFolderInfo *FInfo)
 
 GSM_Error GSM_Phone_N6510::ReplyAddFilePart1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
-	char			buffer[10];
-	wchar_t			name[10];
+	GSM_File 	*File = (GSM_File *)S;
+	char		buffer[10];
+	wchar_t		name[10];
 
 	switch (msg->Buffer.data()[3]) {
 	case 0x03:
 		(*Debug)->Deb("RECEIVED: filesystem 1, file header added\n");
 		sprintf(buffer,"c:\\%i",msg->Buffer.data()[8]*256+msg->Buffer.data()[9]);
 		StringToUnicode(buffer,name);
-		FInfo->SetID(name);
+		File->Info.SetID(name);
 		return GSM_Return_Error(GSM_ERR_NONE);
 	case 0x41:
 		(*Debug)->Deb("RECEIVED: filesystem 1, added part of file\n");
@@ -1028,18 +1028,18 @@ GSM_Error GSM_Phone_N6510::GetNextRootFolderID(wchar_t *ID, GSM_MemoryType *MemT
 	GSM_Error 		error;
 
 	//no filesystem
-	if ((*Phones)->Feature("nofile")==TRUE) {
+	if ((*Phones)->Feature("nofilesystem")==TRUE) {
 		return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	}
 
 	//filesystem 1
-	if ((*Phones)->Feature("file1")==TRUE || (*Phones)->Feature("file1only")==TRUE) {
+	if ((*Phones)->Feature("filesystem1")==TRUE || (*Phones)->Feature("filesystem1only")==TRUE) {
 		if (ID[0] == 0) {
 			ID[0] = 'c'; ID[1] = ':'; ID[2] = '\\'; ID[3] = '1'; ID[4] = 0;
 			*MemType = MEM_PHONE;
 			return GSM_Return_Error(GSM_ERR_NONE);
 		}
-		if ((*Phones)->Feature("file1only")==TRUE) {
+		if ((*Phones)->Feature("filesystem1only")==TRUE) {
 			return GSM_Return_Error(GSM_ERR_EMPTY);
 		}
 	}
@@ -1254,11 +1254,11 @@ GSM_Error GSM_Phone_N6510::AddFolder(FileFolderInfo *FInfo)
 GSM_Error GSM_Phone_N6510::FileSystemFunc(wchar_t *ID, int *Num)
 {
 	//no filesystem
-	if ((*Phones)->Feature("nofile")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("nofilesystem")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	if (ID[0] == 'c' || ID[0] == 'C') {
 		//filesystem1
-		if ((*Phones)->Feature("file1")==FALSE && (*Phones)->Feature("file1only")==FALSE) {
+		if ((*Phones)->Feature("filesystem1")==FALSE && (*Phones)->Feature("filesystem1only")==FALSE) {
 			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 		*Num = 1;
@@ -1274,8 +1274,10 @@ GSM_Error GSM_Phone_N6510::GetJavaGamesFolderID(wchart *ID, BOOLEAN *NeedSubFold
 {
 	GSM_Error	error;
 	char 		buff[80];
+	GSM_FileFolderInfoList		*List;
+	GSM_FileFolderInfoListSubEntry  *SubEntry;
 
-	if ((*Phones)->Feature("nofile")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("nofilesystem")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	if ((*Phones)->Feature("s40_30")==TRUE) {
 		sprintf(buff,"d:\\predefjava\\predefgames");
@@ -1286,38 +1288,55 @@ GSM_Error GSM_Phone_N6510::GetJavaGamesFolderID(wchart *ID, BOOLEAN *NeedSubFold
 	}
 
 	//series 40 1.0 and 2.0 - filesystem 1
-	if (Start) {
-		JavaFInfoSubEntry = NULL;
+	while (1) {
+		error = ReadFolderToCache(StringToUnicodeReturn("c:\\1"), &List);
+		if (error.Code == GSM_ERR_FILE_FOLDER_NOT_EXIST) break;
+		if (error.Code != GSM_ERR_NONE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
-		JavaFInfo.ClearAll();
-		JavaFInfo.Info.SetID(StringToUnicodeReturn("c:\\3"));
-		//we don't need to use GetFolderInfoList
-		//because of it we don't check all error codes
-		error = GetFolderInfoList1(&JavaFInfo, TRUE);
-		if (error.Code == GSM_ERR_NONE) return GSM_Return_Error(GSM_ERR_FOLDER_MORE);
-		return error;
-	} else {
-		if (JavaFInfo.GetNext(&JavaFInfoSubEntry) == FALSE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
-		error = GetFileFolderInfo(&JavaFInfoSubEntry->Info);
-		if (error.Code != GSM_ERR_NONE) return error;
-		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.Name.data(),StringToUnicodeReturn("games"),-1)) {
-			ID->clear();
-			ID->append(JavaFInfoSubEntry->Info.ID.data(),UnicodeLength(JavaFInfoSubEntry->Info.ID.data()));
-			*NeedSubFolder = TRUE;
-			return GSM_Return_Error(GSM_ERR_NONE);
+		SubEntry = NULL;
+		while (List->GetNext(&SubEntry)) {
+			if (!List->SubEntryFullData) {
+				error = GetFileFolderInfo(&SubEntry->Info);
+				if (error.Code != GSM_ERR_NONE) return error;
+			}
+			if (strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"java")) {
+				continue;
+			}
+	
+			error = ReadFolderToCache((wchar_t *)SubEntry->Info.ID.data(), &List);
+			if (error.Code != GSM_ERR_NONE) return error;
+	
+			SubEntry = NULL;
+			while (List->GetNext(&SubEntry)) {
+				if (!List->SubEntryFullData) {
+					error = GetFileFolderInfo(&SubEntry->Info);
+					if (error.Code != GSM_ERR_NONE) return error;
+				}
+
+				if (strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"games")) {
+					continue;
+				}
+
+				ID->clear();
+				ID->append(SubEntry->Info.ID.data(),UnicodeLength(SubEntry->Info.ID.data()));
+				*NeedSubFolder = TRUE;
+				return GSM_Return_Error(GSM_ERR_NONE);
+			}
+			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
-		return GSM_Return_Error(GSM_ERR_FOLDER_MORE);
+		return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	}
-
-	return GSM_Return_Error(GSM_ERR_NONE);
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
 GSM_Error GSM_Phone_N6510::GetJavaAppsFolderID(wchart *ID, BOOLEAN *NeedSubFolder, BOOLEAN Start)
 {
 	GSM_Error	error;
 	char 		buff[80];
+	GSM_FileFolderInfoList		*List;
+	GSM_FileFolderInfoListSubEntry  *SubEntry;
 
-	if ((*Phones)->Feature("nofile")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("nofilesystem")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	//series 40 3.0 - filesystem 2
 	if ((*Phones)->Feature("s40_30")==TRUE) {
@@ -1329,28 +1348,43 @@ GSM_Error GSM_Phone_N6510::GetJavaAppsFolderID(wchart *ID, BOOLEAN *NeedSubFolde
 	}
 
 	//series 40 1.0 and 2.0 - filesystem 1
-	if (Start) {
-		JavaFInfoSubEntry = NULL;
+	while (1) {
+		error = ReadFolderToCache(StringToUnicodeReturn("c:\\1"), &List);
+		if (error.Code == GSM_ERR_FILE_FOLDER_NOT_EXIST) break;
+		if (error.Code != GSM_ERR_NONE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
-		JavaFInfo.ClearAll();
-		JavaFInfo.Info.SetID(StringToUnicodeReturn("c:\\3"));
-		//we don't need to use GetFolderInfoList
-		//because of it we don't check all error codes
-		error = GetFolderInfoList1(&JavaFInfo, TRUE);
-		if (error.Code == GSM_ERR_NONE) return GSM_Return_Error(GSM_ERR_FOLDER_MORE);
-		return error;
-	} else {
-		if (JavaFInfo.GetNext(&JavaFInfoSubEntry) == FALSE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
-		error = GetFileFolderInfo(&JavaFInfoSubEntry->Info);
-		if (error.Code != GSM_ERR_NONE) return error;
-		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.Name.data(),StringToUnicodeReturn("applications"),-1)) {
-			ID->clear();
-			ID->append(JavaFInfoSubEntry->Info.ID.data(),UnicodeLength(JavaFInfoSubEntry->Info.ID.data()));
-			*NeedSubFolder = TRUE;
-			return GSM_Return_Error(GSM_ERR_NONE);
+		SubEntry = NULL;
+		while (List->GetNext(&SubEntry)) {
+			if (!List->SubEntryFullData) {
+				error = GetFileFolderInfo(&SubEntry->Info);
+				if (error.Code != GSM_ERR_NONE) return error;
+			}
+			if (strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"java")) {
+				continue;
+			}
+	
+			error = ReadFolderToCache((wchar_t *)SubEntry->Info.ID.data(), &List);
+			if (error.Code != GSM_ERR_NONE) return error;
+	
+			SubEntry = NULL;
+			while (List->GetNext(&SubEntry)) {
+				if (!List->SubEntryFullData) {
+					error = GetFileFolderInfo(&SubEntry->Info);
+					if (error.Code != GSM_ERR_NONE) return error;
+				}
+
+				if (strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"applications")) {
+					continue;
+				}
+
+				ID->clear();
+				ID->append(SubEntry->Info.ID.data(),UnicodeLength(SubEntry->Info.ID.data()));
+				*NeedSubFolder = TRUE;
+				return GSM_Return_Error(GSM_ERR_NONE);
+			}
+			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
-		return GSM_Return_Error(GSM_ERR_FOLDER_MORE);
+		return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	}
-
-	return GSM_Return_Error(GSM_ERR_NONE);
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
