@@ -274,15 +274,19 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		case PBK_Text_Phone_Video:
 			if (Type == 0x00) Type = NPBK_NUMBER_VIDEO; // no break;
 			Avail = FALSE;
-			for (i=0;i<Features->Numbers.size();i++) {
-				if (Features->Numbers.data()[i] == Type) {
-					Avail = TRUE;
-					break;
+			if (Features!=NULL) {
+				for (i=0;i<Features->Numbers.size();i++) {
+					if (Features->Numbers.data()[i] == Type) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (!Avail) {
-				SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
-				Type = NPBK_NUMBER_GENERAL;
+				if (Type != NPBK_NUMBER_GENERAL) {
+					SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+					Type = NPBK_NUMBER_GENERAL;
+				}
 			}
 			Type2 = NPBK_NUMBER;
 			Type3 = 0x00;
@@ -292,10 +296,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			if (SubEntry->VoiceTag != -1) {
 				SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NONE);
 				Avail = FALSE;
-				for (i=0;i<Features->Types.size();i++) {
-					if (Features->Types.data()[i] == NPBK_VOICETAG_ID) {
-						Avail = TRUE;
-						break;
+				if (Features != NULL) {
+					for (i=0;i<Features->Types.size();i++) {
+						if (Features->Types.data()[i] == NPBK_VOICETAG_ID) {
+							Avail = TRUE;
+							break;
+						}
 					}
 				}
 				if (Avail) {
@@ -318,10 +324,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			if (SubEntry->VoiceTag != -1 && Avail) {
 				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 				Avail = FALSE;
-				for (i=0;i<Features->Types.size();i++) {
-					if (Features->Types.data()[i] == Type2) {
-						Avail = TRUE;
-						break;
+				if (Features != NULL) {
+					for (i=0;i<Features->Types.size();i++) {
+						if (Features->Types.data()[i] == Type2) {
+							Avail = TRUE;
+							break;
+						}
 					}
 				}
 				if (!Avail) {
@@ -416,10 +424,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			Type2 = NPBK_PICTURE_ID;
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == Type2) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == Type2) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (!Avail) {
@@ -449,10 +459,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			break;
 		case PBK_ID_Ringtone:
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == NPBK_RINGTONEFILE_ID) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == NPBK_RINGTONEFILE_ID) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (Avail) {
@@ -460,10 +472,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 				break;
 			}
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == NPBK_RINGTONE_ID) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == NPBK_RINGTONE_ID) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (!Avail) {
@@ -480,10 +494,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			Type2 = NPBK_VIDEO_FILE_ID;
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == Type2) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == Type2) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (!Avail) {
@@ -514,10 +530,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		case PBK_ID_Caller_Group:
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == NPBK_GROUP2_ID) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == NPBK_GROUP2_ID) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			if (Avail) {
@@ -546,20 +564,24 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		if (TempBuffer.size() != 0) {
 			SubEntry->SetError = SetError;
 			Avail = FALSE;
-			for (i=0;i<Features->Types.size();i++) {
-				if (Features->Types.data()[i] == Type2) {
-					Avail = TRUE;
-					break;
+			if (Features != NULL) {
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == Type2) {
+						Avail = TRUE;
+						break;
+					}
 				}
 			}
 			//we check, if we can convert it to other
 			if (!Avail && Type != 0x00) {
 				Type2 = Type3;
-				for (i=0;i<Features->Types.size();i++) {
-					if (Features->Types.data()[i] == Type2) {
-						Avail = TRUE;
-						SubEntry->SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
-						break;
+				if (Features != NULL) {
+					for (i=0;i<Features->Types.size();i++) {
+						if (Features->Types.data()[i] == Type2) {
+							Avail = TRUE;
+							SubEntry->SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+							break;
+						}
 					}
 				}
 			}
@@ -1022,25 +1044,6 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_NDCT34::ReplyGetPBKFeatures(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
-{
-	GSM_PBK_Features *Entry = (GSM_PBK_Features *)S;
-	int 		 i,pos=6;
-
-	Entry->Types.clear();
-	for (i=0;i<msg->Buffer.data()[5]-1;i++) {
-		Entry->Types.push_back(msg->Buffer.data()[pos+4]);
-		pos+=msg->Buffer.data()[pos+3];
-	}
-
-	Entry->Numbers.clear();
-	for (i=0;i<msg->Buffer.data()[pos+4];i++) {
-		Entry->Numbers.push_back(msg->Buffer.data()[pos+5+i]);
-	}
-
-	return GSM_Return_Error(GSM_ERR_NONE);
-}
-
 GSM_Error GSM_Phone_NDCT34::GetPBKFeatures(GSM_PBK_Features *Features)
 {
 	unsigned char Buff[] = {NOKIA_FRAME1, 0x25, 
@@ -1334,6 +1337,8 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar1(GSM_CalendarEntry *Entry)
 	unsigned char	   	NoteType, NoteType2,Buff[2];
 	unsigned int	    	diff;
 
+	Entry->TypeSetError = GSM_Return_Error(GSM_ERR_NONE);
+
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
 		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
@@ -1525,6 +1530,8 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar2(GSM_CalendarEntry *Entry)
 	GSM_Error	      	error;
 	unsigned char	   	Buff[2];
 
+	Entry->TypeSetError = GSM_Return_Error(GSM_ERR_NONE);
+
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
 		switch (SubEntry->GetType()) {
@@ -1587,8 +1594,8 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar2(GSM_CalendarEntry *Entry)
 	} else {
 		/* 6230 and probably other new models handle it differently
 		   we don't make difference from 1980 year */
-		if ((*AllPhones)->Feature("cal62")==TRUE || (*AllPhones)->Feature("cal65")==TRUE ||
-		    (*AllPhones)->Feature("cal35")==TRUE) {
+		if ((*AllPhones)->Feature("calendar1")==TRUE || (*AllPhones)->Feature("calendar65")==TRUE ||
+		    (*AllPhones)->Feature("calendar35")==TRUE) {
 			Date.Year = 1980;
 		}
 		Date.Hour = 22; Date.Minute = 58; Date.Second = 58;
@@ -1627,7 +1634,7 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar2(GSM_CalendarEntry *Entry)
 
 		/* Sometimes we have difference in minutes */
 		if (Entry->Type == Calendar_Type_Meeting) diff = diff / 60;
-		if ((*AllPhones)->Feature("cal35")==FALSE) {
+		if ((*AllPhones)->Feature("calendar35")==FALSE) {
 			if (Entry->Type == Calendar_Type_Memo ||
 			    Entry->Type == Calendar_Type_Call) {
 				diff = diff / 60;
@@ -1650,7 +1657,7 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar2(GSM_CalendarEntry *Entry)
 	switch(Entry->Type) {
 	case Calendar_Type_Meeting:
 	case Calendar_Type_Reminder:
-		if ((*AllPhones)->Feature("cal62")==TRUE || (*AllPhones)->Feature("cal65")==TRUE) {
+		if ((*AllPhones)->Feature("calendar1")==TRUE || (*AllPhones)->Feature("calendar65")==TRUE) {
 			if (Entry->Type == Calendar_Type_Reminder) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		} else {
 			if (Entry->Type == Calendar_Type_Meeting) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
