@@ -13,11 +13,11 @@ class GSM_Protocol_FBUS2:virtual public GSM_Protocol
 {
 public:
         GSM_Protocol_FBUS2(GSM_Device **Dev, DebugInfo **Deb):GSM_Protocol(Dev,Deb) {
-		Info.push_back(GSM_Protocol_Info("serial", "fbus", false, true));
-//		Info.push_back(GSM_Protocol_Info("serial", "dku5fbus", false));
-//		Info.push_back(GSM_Protocol_Info("serial", "dku5", false));
-//		Info.push_back(GSM_Protocol_Info("serial", "dlr3fbus", false));
-//		Info.push_back(GSM_Protocol_Info("serial", "dlr3", false, true));
+		Info.push_back(GSM_Protocol_Info("serial", "fbus",     false, true));
+		Info.push_back(GSM_Protocol_Info("serial", "dku5fbus", false, false));
+		Info.push_back(GSM_Protocol_Info("serial", "dku5",     false, false));
+		Info.push_back(GSM_Protocol_Info("serial", "fbusdlr3", false, true));
+		Info.push_back(GSM_Protocol_Info("serial", "dlr3",     false, true));
 		Pos 			= 0;
 		SendSequenceByte 	= 0;
         }
@@ -44,4 +44,5 @@ private:
         GSM_Protocol_Message    Msg;
 
 	GSM_Error 		WriteSingle(unsigned char *buffer, int length, unsigned char type);
+	GSM_Error 		SendAT(char *command, int length, int timeout);
 };
