@@ -11,6 +11,7 @@
 GSM_Error GSM_Protocol_PHONET::Open(char *Prot)
 {
 	unsigned char Buff[] = {0x04};
+	GSM_Error error;
 
         (*Debug)->Deb("[STATE     : opening protocol phonet]\n");
 
@@ -21,6 +22,11 @@ GSM_Error GSM_Protocol_PHONET::Open(char *Prot)
 
 		return GSM_Return_Error(GSM_ERR_NONE);
 	} else if (!strcmp(Prot,"phonetblue") || !strcmp(Prot,"bluephonet") || !strcmp(Prot,"bluerfphonet")) {
+		if (!strcmp(Prot,"phonetblue")) {
+			error = (*Device)->SetParameters(115200, 8, false, 1);
+			if (error.Code != GSM_ERR_NONE) return error;
+		}
+
 		Frame_ID = 0x19;
 		PC_ID 	 = 0x10;
 
