@@ -1,6 +1,7 @@
 /* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
-#include "backtext.cpp"
+#include "_backxml.cpp"
+#include "_backtxt.cpp"
 #include "gsmback.h"
 
 void GSM_Backup::GetFileFunctions(GSM_Backup_FileFormatNum Num, GSM_Backup_FileFormatFunctions *Func)
@@ -404,6 +405,7 @@ GSM_Error GSM_Backup::ReadFromFile(char *FileName)
 
 GSM_Error GSM_Backup::SaveToFile(char *FileName)
 {
+	if (StringCaseStr(FileName,".xml")) return SaveToXMLFile(FileName);
 	return SaveToTextFile(FileName);
 }
 
@@ -548,7 +550,7 @@ void GSM_Backup::Add_ToDo(GSM_ToDoEntry *En)
 	}
 }
 
-void GSM_Backup::Add_MMS(GSM_MMSFile *En)
+void GSM_Backup::Add_MMS(GSM_MMSEntry *En)
 {
 	GSM_Backup_MMSEntry *Entry,*Entry2;
 
@@ -843,12 +845,12 @@ GSM_Backup_MMSEntry *GSM_Backup_MMSEntry::GetNext()
 	return Next;
 }
 
-GSM_MMSFile *GSM_Backup_MMSEntry::GetEntry()
+GSM_MMSEntry *GSM_Backup_MMSEntry::GetEntry()
 {
 	return Entry;
 }
 
-void GSM_Backup_MMSEntry::SetEntry(GSM_MMSFile *En)
+void GSM_Backup_MMSEntry::SetEntry(GSM_MMSEntry *En)
 {
 	Entry = En;
 }
