@@ -6,12 +6,11 @@
 
 #include "../../misc/files.h"
 #include "../../misc/misc.h"
-#include "../sms/gsmsms.h"
-#include "../sms/smsmulti.h"
+#include "../smsmms/gsmsms.h"
+#include "../smsmms/gsmmsg.h"
 #include "../gsmmisc.h"
 #include "../gsmpbk.h"
 #include "../gsmcal.h"
-#include "../gsmdata.h"
 
 #ifndef gsm_back_h
 #define gsm_back_h
@@ -85,13 +84,13 @@ public:
         ~GSM_Backup_MMSEntry();
 
         GSM_Backup_MMSEntry     *GetNext();
-	GSM_MMSFile		*GetEntry();
+	GSM_MMSEntry		*GetEntry();
 private:
         void                    SetNext(GSM_Backup_MMSEntry *Nxt);
-        void                    SetEntry(GSM_MMSFile *En);
+        void                    SetEntry(GSM_MMSEntry *En);
 
         GSM_Backup_MMSEntry     *Next;
-        GSM_MMSFile             *Entry;
+        GSM_MMSEntry             *Entry;
 };
 
 class GSM_Backup_JADEntry {
@@ -172,7 +171,7 @@ public:
         void                    Add_PBK(GSM_PBKEntry *En);
         void                    Add_Cal(GSM_CalendarEntry *En);
         void                    Add_SMS(GSM_SMSList *En);
-        void                    Add_MMS(GSM_MMSFile *En);
+        void                    Add_MMS(GSM_MMSEntry *En);
         void                    Add_JAD(GSM_File *En);
         void                    Add_Note(GSM_NoteEntry *En);
         void                    Add_ToDo(GSM_ToDoEntry *En);
@@ -210,6 +209,12 @@ private:
 	void 			SaveTextFilePart(wchar_t *Text, FILE *file, BOOLEAN LineEnd);
 	void 			ReadTextFilePart(wchar_t *Src, wchart *Dest);
 	GSM_Error 		FindTextFileChecksum(INI_File *File, char *checksum);
+	GSM_Error 		SaveToXMLFile(char *FileName);
+	GSM_Error 		SaveCalendarToXMLFile(FILE *file);
+	GSM_Error 		SavePbkToXMLFile(FILE *file);
+	GSM_Error 		SaveNoteToXMLFile(FILE *file);
+	GSM_Error 		SaveToDoToXMLFile(FILE *file);
+	void 			SaveXMLFilePart(wchar_t *Text, FILE *file, BOOLEAN LineEnd);
 
         void                    Add_SMS0(GSM_Backup_SMSEntry **Start, GSM_SMSList *En);
 };
