@@ -47,6 +47,11 @@ typedef enum {
 	PBK_Bool_PTT_Subscribed
 } GSM_PBK_SubEntryType;
 
+typedef enum {
+	VCARD_10 = 1,
+	VCARD_21
+} GSM_VCARDType;
+
 class GSM_PBKSubEntry
 {
 	friend class GSM_PBKEntry;
@@ -96,6 +101,8 @@ public:
 	GSM_Error	 	AddDateTime(GSM_PBK_SubEntryType Typ, GSM_DateTime DT2);
 	GSM_Error	 	AddLong(GSM_PBK_SubEntryType Typ, long long2);
 	GSM_Error	 	AddBool(GSM_PBK_SubEntryType Typ, bool bool2);
+	GSM_Error 		EncodeToVCARD(unsignedstring *dest, GSM_VCARDType Type);
+	GSM_Error 		DecodeFromVCARD(unsignedstring *src);
 private:
 	GSM_PBKSubEntry		*Entries;
 };
