@@ -295,7 +295,7 @@ int GSM_SMSMMSDecodedEntry::DecodeContentType(unsignedstring *Buff, long *Pos, u
 	return type;
 }
 
-void GSM_SMSMMSDecodedEntry::DecodeAddress(unsignedstring *buffer, GSM_MMS_Types *Type)
+void GSM_SMSMMSDecodedEntry::DecodeAddress(unsignedstring *buffer, GSM_MSG_Types *Type)
 {
 	unsignedstring buff2;
 
@@ -329,36 +329,36 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 		SubEntry=new GSM_SMSMMSDecodedSubEntry;
 		switch (File->Buffer.data()[pos++] & 0x7F) {
 		case 0x01:
-			SubEntry->Type = MMS_Address_Phone_BCC;
+			SubEntry->Type = MSG_MMS_Address_Phone_BCC;
 			DecodeEncodedString(&File->Buffer, &pos, &buff3);
 			DecodeAddress(&buff3, &SubEntry->Type);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x02:
-			SubEntry->Type = MMS_Address_Phone_CC;
+			SubEntry->Type = MSG_MMS_Address_Phone_CC;
 			DecodeEncodedString(&File->Buffer, &pos, &buff3);
 			DecodeAddress(&buff3, &SubEntry->Type);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x03:
-			SubEntry->Type = MMS_Text_ContentLocation;
+			SubEntry->Type = MSG_MMS_Text_ContentLocation;
 			DecodeText(&File->Buffer, &pos, &buff3);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x04:
-			SubEntry->Type = MMS_Text_ContentType;
+			SubEntry->Type = MSG_MMS_Text_ContentType;
 			type = DecodeContentType(&File->Buffer, &pos, &buff3, &buff2, &name, version);
 			if (type == -1) return GSM_Return_Error(GSM_ERR_UNKNOWN);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x05:
-			SubEntry->Type = MMS_DT_DateTime;
+			SubEntry->Type = MSG_MMS_DT_DateTime;
 			timet = DecodeLonginteger(&File->Buffer, &pos);
 			Date=TimeT2GSMDateTime(&timet);
 			memcpy(&SubEntry->DT,&Date,sizeof(GSM_DateTime));
 			break;
 		case 0x06:
-			SubEntry->Type = MMS_Bool_Report;
+			SubEntry->Type = MSG_MMS_Bool_Report;
 			switch(File->Buffer.data()[pos++]) {
 				case 0x80: SubEntry->Bool = TRUE;  break;
 				case 0x81: SubEntry->Bool = FALSE; break;
@@ -366,19 +366,19 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			}
 			break;
 		case 0x08:			
-			SubEntry->Type = MMS_DT_Expiry;
+			SubEntry->Type = MSG_MMS_DT_Expiry;
 			z = DecodeLonginteger(&File->Buffer, &pos);
 			sprintf(buff,"%i",z);
 			SubEntry->Text.append(StringToUnicodeReturn(buff),UnicodeLength(StringToUnicodeReturn(buff)));
 			break;
 		case 0x09:
-			SubEntry->Type = MMS_Address_Phone_Source;
+			SubEntry->Type = MSG_MMSSMS_Address_Phone_Source;
 			DecodeEncodedString(&File->Buffer, &pos, &buff3);
 			DecodeAddress(&buff3, &SubEntry->Type);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x0A:
-			SubEntry->Type = MMS_Text_MessageClass;
+			SubEntry->Type = MSG_MMS_Text_MessageClass;
 			switch (File->Buffer.data()[pos++]) {
 				case 0x80: sprintf(buff,"personal");  	   	break;
 				case 0x81: sprintf(buff,"advertisement"); 	break;
@@ -389,12 +389,12 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			SubEntry->Text.append(StringToUnicodeReturn(buff),UnicodeLength(StringToUnicodeReturn(buff)));
 			break;
 		case 0x0B:
-			SubEntry->Type = MMS_Text_MessageID;
+			SubEntry->Type = MSG_MMS_Text_MessageID;
 			DecodeText(&File->Buffer, &pos, &buff3);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x0C:
-			SubEntry->Type=MMS_Text_MessageType;
+			SubEntry->Type=MSG_MMS_Text_MessageType;
 			switch (File->Buffer.data()[pos++]) {
 				case 0x80: sprintf(buff,"m-send-req");  	   	break;
 				case 0x81: sprintf(buff,"m-send-conf"); 	   	break;
@@ -408,7 +408,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			SubEntry->Text.append(StringToUnicodeReturn(buff),UnicodeLength(StringToUnicodeReturn(buff)));
 			break;
 		case 0x0D:
-			SubEntry->Type = MMS_Text_Version;
+			SubEntry->Type = MSG_MMS_Text_Version;
 			DecodeVersion(&File->Buffer, &pos, &buff3, &version);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;			
@@ -416,7 +416,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			printf("  Message size      : not done yet\n");
 			return GSM_Return_Error(GSM_ERR_UNKNOWN);
 		case 0x0F:
-			SubEntry->Type=MMS_Text_Priority;
+			SubEntry->Type=MSG_MMS_Text_Priority;
 			switch (File->Buffer.data()[pos++]) {
 				case 0x80: sprintf(buff,"low");  	   	break;
 				case 0x81: sprintf(buff,"normal"); 	   	break;
@@ -426,7 +426,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			SubEntry->Text.append(StringToUnicodeReturn(buff),UnicodeLength(StringToUnicodeReturn(buff)));
 			break;
 		case 0x10:
-			SubEntry->Type = MMS_Bool_Read_Reply;
+			SubEntry->Type = MSG_MMS_Bool_Read_Reply;
 			switch(File->Buffer.data()[pos++]) {
 				case 0x80: SubEntry->Bool = TRUE;  break;
 				case 0x81: SubEntry->Bool = FALSE; break;
@@ -434,7 +434,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			}
 			break;
 		case 0x11:
-			SubEntry->Type = MMS_Bool_Report_Allowed;
+			SubEntry->Type = MSG_MMS_Bool_Report_Allowed;
 			switch(File->Buffer.data()[pos++]) {
 				case 0x80: SubEntry->Bool = TRUE;  break;
 				case 0x81: SubEntry->Bool = FALSE; break;
@@ -463,7 +463,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			printf("  Sender visibility : not done yet\n");
 			return GSM_Return_Error(GSM_ERR_UNKNOWN);
 		case 0x15:
-			SubEntry->Type=MMS_Text_Status;
+			SubEntry->Type=MSG_MMS_Text_Status;
 			switch (File->Buffer.data()[pos++]) {
 				case 0x80: sprintf(buff,"expired");  	   	break;
 				case 0x81: sprintf(buff,"retrieved"); 	   	break;
@@ -475,19 +475,19 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 			SubEntry->Text.append(StringToUnicodeReturn(buff),UnicodeLength(StringToUnicodeReturn(buff)));
 			break;
 		case 0x16:
-			SubEntry->Type=	MMS_Text_Subject;
+			SubEntry->Type=	MSG_MMS_Text_Subject;
 			DecodeEncodedString(&File->Buffer, &pos, &buff3);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x17:
-			SubEntry->Type = MMS_Address_Phone_Destination;
+			SubEntry->Type = MSG_MMS_Address_Phone_Destination;
 			DecodeEncodedString(&File->Buffer, &pos, &buff3);
 			DecodeAddress(&buff3, &SubEntry->Type);
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		case 0x18:
 			DecodeText(&File->Buffer, &pos, &buff3);
-			SubEntry->Type = MMS_Text_TransactionID;
+			SubEntry->Type = MSG_MMS_Text_TransactionID;
 			SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 			break;
 		default:
@@ -504,7 +504,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 
 	for (j=0;j<parts;j++) {
 		SubEntry=new GSM_SMSMMSDecodedSubEntry;
-		SubEntry->Type=MMS_File;
+		SubEntry->Type=MSG_MMSSMS_File;
 
 		headlen = DecodeUintvar(&File->Buffer, &pos);
 		datalen = DecodeUintvar(&File->Buffer, &pos);
@@ -563,7 +563,7 @@ GSM_Error GSM_SMSMMSDecodedEntry::ReadFromMMS(GSM_File *File)
 	if (pos>(long)File->Buffer.size()) return GSM_Return_Error(GSM_ERR_FILE_TOO_SHORT);
 	if (pos<(long)File->Buffer.size()) {
 		SubEntry=new GSM_SMSMMSDecodedSubEntry;
-		SubEntry->Type=MMS_Unknown;
+		SubEntry->Type=MSG_Unknown;
 		SubEntry->File.Buffer.append(File->Buffer.data()+pos,File->Buffer.size()-pos);
 		SubEntry->File.Info.Size=File->Buffer.size()-pos;
 		Add(SubEntry);
