@@ -138,6 +138,7 @@ GSM_Error GSM_DecodeSMSText(wchar_t *Destination, const unsigned char *Source, i
 		i+=7;
 	} while ((i-udhlen)%i<0);
 	len2 = len-(udhlen*8 + (i-udhlen)%i) / 7;
+//  	len2 = len;
 	j = 1;
 	for (i=1;i<(unsigned int)udhlen*7;i++) {
 		if (j == 128) {
@@ -199,7 +200,7 @@ static unsigned char ConvertTable[] =
 
 GSM_Error GSM_EncodeSMSText(unsigned char *Destination, const wchar_t *Source, int *GetFromSRC, int *SavedInSMS, int MaxInSMS, int *UsedInSMS, int udhlen)
 {
-	int		pos=0,j,destbit,z,gsmcharlen,l=0;
+	unsigned int	pos=0,j,destbit,z,gsmcharlen,l=0;
 	unsigned char 	gsmchar[2];
 	BOOLEAN 	found;
 	wchar_t 	srcchar;
@@ -303,7 +304,7 @@ unsigned char GSM_SMSEntry::MakeSMSIDFromTime(void)
 
 GSM_Error GSM_SMSEntry::DecodeUDH(UDHList *List)
 {
-        int 			i=0,j,pos=0;
+        int 			i=0,j,pos=1;
 	unsignedstring 		UDH;
 	GSM_Error 		error;
 	BOOLEAN			wrong;
@@ -363,6 +364,9 @@ GSM_SMSEntry::GSM_SMSEntry()
 
 	Icon = SMS_UnRead;
 	SaveDateTimeAvailable = FALSE;
+
+
+	SetCoding(SMS_Coding_Default_No_Compression);
 }
 
 GSM_SMSEntry::~GSM_SMSEntry() 
@@ -472,7 +476,7 @@ GSM_Error GSM_SMSEntry::SetCoding(SMS_Coding_Type Coding)
 		case SMS_Coding_8bit:
 			TPDCS &= 0xF3; 	// set bit 3 to 0
 			TPDCS += 4; 	// set bit 3 to 1
-			return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
+			//return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
 		}
 	} else if ((TPDCS & 0xF0) >= 0x40 && (TPDCS & 0xF0) <= 0xB0) {
 		/* bits 7..4 set to 0100 ... 1011 */
@@ -658,14 +662,14 @@ GSM_Error GSM_SMSEntry::SetDecodedText(wchar_t *Text)
 			TMP.push_back(Text[i]/256);
 			TMP.push_back(Text[i]%256);
 		}
-		return SetText(&TMP);
+		return SetText(&TMP,UnicodeLength(Text)*2);
 	case SMS_Coding_Default_No_Compression:
 //		error = GSM_EncodeSMSText(Buffer, Text, &j, 133-TMP2.size(), TMP2.size());
 		error = GSM_EncodeSMSText(Buffer, Text, &x, &j, 140-TMP2.size(), &used, TMP2.size());
 		if (error.Code != GSM_ERR_NONE) return error;
 		for (i=0;i<used;i++) TMP.push_back(Buffer[i]);
 //printf("%i\n",(j*7/8));
-		return SetText(&TMP);		
+		return SetText(&TMP,j);		
 	case SMS_Coding_Unicode_Compression:
 	case SMS_Coding_Default_Compression:
 		return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
@@ -687,7 +691,7 @@ GSM_Error GSM_SMSEntry::GetText(unsignedstring *Text)
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_SMSEntry::SetText(unsignedstring *Text)
+GSM_Error GSM_SMSEntry::SetText(unsignedstring *Text, int l)
 {
 	unsignedstring 	TMP;
 	int		Len;
@@ -702,14 +706,16 @@ GSM_Error GSM_SMSEntry::SetText(unsignedstring *Text)
 	switch (GetCoding()) {
 	case SMS_Coding_Unicode_No_Compression:
 		if ((Text->size() % 2) != 0) return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
-		TPUDL = Len;
+		TPUDL = l*2;
 		break;
 	case SMS_Coding_Default_No_Compression:
-		TPUDL = Len;
+		TPUDL = l;
+		break;
+	case SMS_Coding_8bit:
+		TPUDL = l;
 		break;
 	case SMS_Coding_Unicode_Compression:
 	case SMS_Coding_Default_Compression:
-	case SMS_Coding_8bit:
 		return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
 	}
 
@@ -781,8 +787,39 @@ GSM_Error GSM_SMSEntry::SetSMSCTime(GSM_DateTime *DT)
 {
 	return SetSMSDateTime(DT,SMSCTime);
 }
+
+/* GSM 03.40 section 9.2.3.25 (TP Reject Duplicates) */
+BOOLEAN GSM_SMSEntry::SetRejectDuplicates(BOOLEAN enable)
+{
+	if (GetType() != SMS_Submit) return FALSE;
+
+	firstbyte &= 0xFB;
+	if (enable==TRUE) firstbyte+=0x04;
+	return TRUE;
+}
 				
-//tocheck
+BOOLEAN GSM_SMSEntry::SetReplace(int i)
+{
+	if (GetType() == SMS_Report) return FALSE;
+
+	if (i == -1) {
+		TPPID=0;
+	} else {
+		if (i<-1 || i>7) return FALSE;
+		TPPID=0x40+i;
+	}
+	return TRUE;
+}
+
+BOOLEAN GSM_SMSEntry::GetReplace(int *i)
+{
+	if (GetType() == SMS_Report) return FALSE;
+
+	(*i) = -1;
+	if (TPPID >= 0x40 && TPPID < 0x48) (*i) = TPPID - 0x40;
+	return TRUE;
+}
+
 GSM_Error GSM_SMSEntry::GetUDH(unsignedstring *UDH)
 {
 	unsigned int Len;
@@ -799,12 +836,10 @@ GSM_Error GSM_SMSEntry::GetUDH(unsignedstring *UDH)
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-//tocheck
 GSM_Error GSM_SMSEntry::SetUDH(unsignedstring *Text) 
 {
 	unsignedstring TMP;
-
-	firstbyte |= 0x40;
+int p,w;
 
 	GetUDH(&TMP);
 	if (TMP.size() != 0) {
@@ -813,10 +848,33 @@ GSM_Error GSM_SMSEntry::SetUDH(unsignedstring *Text)
 		TMP.append((const unsigned char *)UserData.data(),UserData.size());
 	}
 
+	firstbyte |= 0x40;
+
 	UserData.clear();
 	UserData.append((const unsigned char *)Text->data(),Text->size());
 	UserData.append((const unsigned char *)TMP.data(),TMP.size());
 
+	switch (GetCoding()) {
+	case SMS_Coding_Unicode_No_Compression:
+		TPUDL+=Text->size();
+		break;
+	case SMS_Coding_Default_No_Compression:
+		p = 0;
+		do {
+			p+=7;
+			w=(p-Text->size())%p;
+		} while (w<0);
+		TPUDL+=(Text->size()*8+w)/7;
+//		TPUDL+=(Text->size());
+		break;
+	case SMS_Coding_8bit:
+		TPUDL+=Text->size();
+		break;
+	case SMS_Coding_Unicode_Compression:
+	case SMS_Coding_Default_Compression:
+		return GSM_Return_Error(GSM_ERR_GPLUS_NOT_SUPPORTED);
+	}
+
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
