@@ -114,30 +114,34 @@ void Identify(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
 	unsigned char 		IMEI[20], Model[50], Model2[50], Firm[50], Man[50], Firm2[50];
 
 
-    GSM_SMSMMSDecodedEntry Decoded;
-    GSM_SMSMMSDecodedSubEntry *Decoded2;
-    GSM_SMSList List;
-    GSM_SMSListSubEntry *SMS2;
-    int i,left;
-    wchar_t x[2];
-    List.ClearAll();
-    Decoded2 = new GSM_SMSMMSDecodedSubEntry;
-    Decoded2->Type = MMS_File;
-    Decoded2->Text.append(StringToUnicodeReturn("text/plain"));
+//    GSM_SMSMMSDecodedEntry Decoded;
+//    GSM_SMSMMSDecodedSubEntry *Decoded2;
+//    GSM_SMSList List;
+//    GSM_SMSListSubEntry *SMS2;
+//unsignedstring UDH;
+//    int i,left;
+//    wchar_t x[2];
+//    List.ClearAll();
+//    Decoded2 = new GSM_SMSMMSDecodedSubEntry;
+//    Decoded2->Type = MSG_MMSSMS_File;
+//    Decoded2->Text.append(StringToUnicodeReturn("text/plain"));
 //    UnicodeToUTF8(StringToUnicodeReturn("ddddddddddddddddddddddddxxxxxxxxdddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddd"), &Decoded2->File.Buffer);
   //  x[0]=1*256+5;
-x[0]='{';
-    x[1] = 0;
-    UnicodeToUTF8(x, &Decoded2->File.Buffer);
-    Decoded.Add(Decoded2);
-    Decoded.SaveToSMS(&List, SMS_Text_Short,&left);
-    i=0;
-    SMS2 = NULL;
-    while (List.GetNext(&SMS2)) {
-        i++;
-	printf("%i\n",SMS2->GetSMS()->UserData.size());
-    }
-    printf("sms num %i %i\n",i,left);
+//x[0]='{';
+//    x[1] = 0;
+//    UnicodeToUTF8(x, &Decoded2->File.Buffer);
+//    Decoded.Add(Decoded2);
+//    Decoded.SaveToSMS(&List, SMS_Text_Short,&left);
+//    i=0;
+//int w;
+//    SMS2 = NULL;
+//    while (List.GetNext(&SMS2)) {
+//        i++;
+//	printf("%i\n",SMS2->GetSMS()->UserData.size());
+//SMS2->GetSMS()->GetUDH(&UDH);
+//for (w=0;w<UDH.size();w++) printf("%02x ",UDH.data()[w]);
+//    }
+//    printf("sms num %i %i\n",i,left);
 
 //unsignedstring x;
 //int len2,w,z,m;
