@@ -237,6 +237,7 @@ int DisplaySingleSMS(GSM_SMSEntry *SMS, GSM_Backup *Backup)
 	BOOLEAN 		start = TRUE;
 	unsigned int		j=0, smsnum=0, smsparts=0, z=0, lastfolder=0,num=0;
 	GSM_SMSNumbersSubEntry  *Number;
+	int rw;
 
 	switch (SMS->GetType()) {
 	case SMS_Deliver:
@@ -248,6 +249,13 @@ int DisplaySingleSMS(GSM_SMSEntry *SMS, GSM_Backup *Backup)
 		printf("    Sending date & time : %02i:%02i:%02i %02i-%02i-%04i %s\n",
 			DT.Hour,DT.Minute,DT.Second,DT.Day,DT.Month,DT.Year,
 			DayOfWeekStr(DT.Year,DT.Month,DT.Day));
+
+		if (SMS->GetReplace(&rw)) {
+           //     	tmp = SMSDetailsWxListCtrl->InsertItem(EntryNum++, "   Replacing ID", 0);
+	       //         SMSDetailsWxListCtrl->SetItemData(tmp, 0);
+	       //         sprintf(buff,"%i",z);
+	       //         SMSDetailsWxListCtrl->SetItem(tmp, 1, buff);
+		}
 		/* no break */
 	case SMS_Submit:
 		if (SMS->GetType() == SMS_Submit)   printf("    SMS Submit\n");
