@@ -57,8 +57,19 @@ CfgDlg::CfgDlg(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2, wxWindow *parent, wx
         WxButton1->SetLabel("View set");
     	EditMode = true;
     }
-    WxComboBox3->SetSelection(0);
-    SelectSet();
+    for (i=1;i<12;i++) {
+        s->ReadCfg(i,CFG);
+        if (!strcmp(CFG->Active,"yes")) {
+            Number   = i-1;
+            WxComboBox3->SetSelection(i-1);
+            SelectSet();
+            break;
+        }
+    }
+    if (i==12) {
+        WxComboBox3->SetSelection(0);
+        SelectSet();
+    }
 }
 
 CfgDlg::~CfgDlg()
@@ -75,17 +86,31 @@ void CfgDlg::CreateGUIControls()
 
 	SetTitle(wxT("Configuration for phone connection"));
 	SetIcon(wxNullIcon);
-	SetSize(8,8,489,285);
+	SetSize(8,8,489,400);
 	Center();
 	
 
+	WxStaticText10 = new wxStaticText(this, ID_WXSTATICTEXT10, wxT("Used model features"), wxPoint(13,185), wxDefaultSize, 0, wxT("WxStaticText10"));
+
+	WxEdit6 = new wxTextCtrl(this, ID_WXEDIT6, wxT(""), wxPoint(132,182), wxSize(338,23), 0, wxDefaultValidator, wxT("WxEdit6"));
+
+	WxEdit5 = new wxTextCtrl(this, ID_WXEDIT5, wxT("WxEdit5"), wxPoint(132,208), wxSize(338,49), wxNO_BORDER | wxTE_READONLY | wxTE_MULTILINE, wxDefaultValidator, wxT("WxEdit5"));
+	WxEdit5->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE));
+
+	WxStaticText9 = new wxStaticText(this, ID_WXSTATICTEXT9, wxT("Available model features"), wxPoint(13,209), wxDefaultSize, 0, wxT("WxStaticText9"));
+
+	WxEdit4 = new wxTextCtrl(this, ID_WXEDIT4, wxT("WxEdit4"), wxPoint(132,160), wxSize(338,22), wxTE_READONLY, wxDefaultValidator, wxT("WxEdit4"));
+	WxEdit4->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_ACTIVEBORDER));
+
+	WxStaticText8 = new wxStaticText(this, ID_WXSTATICTEXT8, wxT("Default model features"), wxPoint(13,161), wxDefaultSize, 0, wxT("WxStaticText8"));
+
 	WxStaticText7 = new wxStaticText(this, ID_WXSTATICTEXT7, wxT("Set name"), wxPoint(12,70), wxDefaultSize, 0, wxT("WxStaticText7"));
 
 	WxStaticText6 = new wxStaticText(this, ID_WXSTATICTEXT6, wxT("WxStaticText6"), wxPoint(132,6), wxDefaultSize, 0, wxT("WxStaticText6"));
 
 	WxStaticText5 = new wxStaticText(this, ID_WXSTATICTEXT5, wxT("Config file"), wxPoint(12,8), wxDefaultSize, 0, wxT("WxStaticText5"));
 
-	WxEdit3 = new wxTextCtrl(this, ID_WXEDIT3, wxT("WxEdit3"), wxPoint(197,197), wxSize(270,20), 0, wxDefaultValidator, wxT("WxEdit3"));
+	WxEdit3 = new wxTextCtrl(this, ID_WXEDIT3, wxT("WxEdit3"), wxPoint(198,308), wxSize(270,20), 0, wxDefaultValidator, wxT("WxEdit3"));
 
 	WxButton1 = new wxButton(this, ID_WXBUTTON1, wxT("Edit set"), wxPoint(407,26), wxSize(62,20), 0, wxDefaultValidator, wxT("WxButton1"));
 
@@ -96,9 +121,9 @@ void CfgDlg::CreateGUIControls()
 
 	WxStaticText4 = new wxStaticText(this, ID_WXSTATICTEXT4, wxT("Selected set"), wxPoint(12,31), wxDefaultSize, 0, wxT("WxStaticText4"));
 
-	WxCheckBox3 = new wxCheckBox(this, ID_WXCHECKBOX3, wxT("check online info on startup (send codename and product code)"), wxPoint(12,173), wxSize(357,18), 0, wxDefaultValidator, wxT("WxCheckBox3"));
+	WxCheckBox3 = new wxCheckBox(this, ID_WXCHECKBOX3, wxT("check online info on startup (send codename and product code)"), wxPoint(13,278), wxSize(357,18), 0, wxDefaultValidator, wxT("WxCheckBox3"));
 
-	WxCheckBox2 = new wxCheckBox(this, ID_WXCHECKBOX2, wxT("add log from communication to file"), wxPoint(12,199), wxSize(182,18), 0, wxDefaultValidator, wxT("WxCheckBox2"));
+	WxCheckBox2 = new wxCheckBox(this, ID_WXCHECKBOX2, wxT("add log from communication to file"), wxPoint(13,309), wxSize(182,18), 0, wxDefaultValidator, wxT("WxCheckBox2"));
 
 	wxArrayString arrayStringFor_WxComboBox1;
 	WxComboBox1 = new wxComboBox(this, ID_WXCOMBOBOX1, wxT("WxComboBox1"), wxPoint(132,87), wxSize(338,21), arrayStringFor_WxComboBox1, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox1"));
@@ -108,11 +133,11 @@ void CfgDlg::CreateGUIControls()
 	wxArrayString arrayStringFor_WxComboBox2;
 	WxComboBox2 = new wxComboBox(this, ID_WXCOMBOBOX2, wxT("WxComboBox2"), wxPoint(132,135), wxSize(338,21), arrayStringFor_WxComboBox2, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox2"));
 
-	WxCheckBox1 = new wxCheckBox(this, ID_WXCHECKBOX1, wxT("set phone clock from your computer"), wxPoint(12,156), wxSize(296,18), 0, wxDefaultValidator, wxT("WxCheckBox1"));
+	WxCheckBox1 = new wxCheckBox(this, ID_WXCHECKBOX1, wxT("set phone clock from your computer"), wxPoint(13,262), wxSize(296,18), 0, wxDefaultValidator, wxT("WxCheckBox1"));
 
-	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(40,230), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
+	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(39,344), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
 
-	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(361,232), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
+	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(360,345), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
 
 	WxStaticText3 = new wxStaticText(this, ID_WXSTATICTEXT3, wxT("Phone model"), wxPoint(13,134), wxDefaultSize, 0, wxT("WxStaticText3"));
 
@@ -120,12 +145,14 @@ void CfgDlg::CreateGUIControls()
 
 	WxStaticText1 = new wxStaticText(this, ID_WXSTATICTEXT1, wxT("Connection type"), wxPoint(12,90), wxDefaultSize, 0, wxT("WxStaticText1"));
 
-	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Set parameters"), wxPoint(2,48), wxSize(476,179));
+	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Set parameters"), wxPoint(2,48), wxSize(476,289));
 	////GUI Items Creation End
 }
 
 void CfgDlg::OnClose(wxCloseEvent& /*event*/)
 {
+    EndModal(wxID_CANCEL);
+
 	Destroy();
 }
 
@@ -135,7 +162,7 @@ void CfgDlg::SelectSet()
 	list<GSM_Phone_Info>::iterator 		phoinfo;
     GSM_Protocol            		    *pro;
     GSM_Phone               		    *pho;
-    int                                 Num=0;
+    int                                 Num=0,i;
     char                                buff[200];
     bool                                EditMode2;
 
@@ -170,10 +197,12 @@ void CfgDlg::SelectSet()
             sprintf(buff,"%s (%s)",(*phoinfo).Model,(*phoinfo).CodeNameModel);
             WxComboBox2->Append(buff);
             Num++;
-            if (!strcmp(CFG->Phone,(*phoinfo).Model)) WxComboBox2->SetSelection(Num);
+            if (!strcmp(CFG->Phone,(*phoinfo).Model)) {
+                WxComboBox2->SetValue(buff);
+            }
         }
     }
-
+    
     //connection
     SelectChoice2();
     
@@ -181,15 +210,21 @@ void CfgDlg::SelectSet()
     WxStaticText2->Enable(EditMode);
     WxStaticText3->Enable(EditMode);
     WxStaticText7->Enable(EditMode);
+    WxStaticText8->Enable(EditMode);
     WxStaticBox1->Enable(EditMode);    
     WxEdit1->Enable(EditMode);
     WxEdit2->Enable(EditMode);
     WxEdit3->Enable(EditMode);
+    WxEdit4->Enable(EditMode);
     WxComboBox1->Enable(EditMode);
     WxComboBox2->Enable(EditMode);
     WxCheckBox1->Enable(EditMode);
     WxCheckBox2->Enable(EditMode);
     WxCheckBox3->Enable(EditMode);
+    
+    if (CFG->Features[0] != 0) {
+        WxEdit6->SetLabel(CFG->Features);
+    }    
 }
 
 typedef struct {
@@ -202,7 +237,8 @@ X   X2[] = {
     "bluerfphonet", "Nokia - bluetooth for old models (with Microsoft stack)", "Phone address",
     "bluephonet", "Nokia - bluetooth for new models (with Microsoft stack)", "Phone address or empty",
     "phonetblue", "Nokia - bluetooth over 'Nokia PC Suite' service (with any stack)", "Serial port",
-    "irdaphonet", "Nokia - infrared (in N82xx with Snake, not for N6110/6130/6150)", "Device",
+    "irdaphonet", "Nokia - infrared (in N8210/8250 with 2-player Snake)", "Device",
+//    "irdaobex", "OBEX - infrared", "Device",
     "dku2", "Nokia - DKU2 USB cable for PopPort (with Nokia driver)", "Device",
     "dku5", "Nokia - DKU5 USB cable for PopPort (with Nokia driver)", "Device",
     "dlr3", "Nokia - DLR3 cable (for N6210/6310/6310i)", "Serial port",
@@ -241,7 +277,7 @@ void CfgDlg::SelectChoice1()
     }
 }
 
-//phone model
+//phone model & connection
 void CfgDlg::SelectChoice2()
 {
     char                                buff[200];
@@ -267,6 +303,14 @@ void CfgDlg::SelectChoice2()
                 }
             }
         }
+        WxStaticText8->Show(FALSE);
+        WxStaticText9->Show(FALSE);
+        WxStaticText10->Show(FALSE);
+        WxEdit4->Show(FALSE);
+        WxEdit5->Show(FALSE);
+        WxEdit6->Show(FALSE);
+        WxEdit4->SetLabel("ala");
+        WxEdit6->SetLabel("");
     } else {
         pho = NULL;
         while(1) {
@@ -277,6 +321,19 @@ void CfgDlg::SelectChoice2()
                 if (strcmp(buff,WxComboBox2->GetStringSelection())) continue;
                 sprintf(CFG->Phone,"%s",(*phoinfo).Model);
 
+                WxStaticText8->Show(pho->ModuleFeatures.size()!=0);
+                WxStaticText9->Show(pho->ModuleFeatures.size()!=0);
+                WxStaticText10->Show(pho->ModuleFeatures.size()!=0);
+                WxEdit4->Show(pho->ModuleFeatures.size()!=0);
+                WxEdit5->Show(pho->ModuleFeatures.size()!=0);
+                WxEdit6->Show(pho->ModuleFeatures.size()!=0);
+                
+                WxEdit5->SetLabel(pho->ModuleFeatures.data());
+                if (CFG->Features[0] == 0) {
+                    WxEdit6->SetLabel((*phoinfo).Features);
+                }
+                WxEdit4->SetLabel((*phoinfo).Features);
+               
                 pro = NULL;
                 while(1) {
                     if (!s->Protocols->GetNext(&pro)) break;
@@ -291,6 +348,7 @@ void CfgDlg::SelectChoice2()
                         }
                     }
                 }
+                break;
             }
         }
     }
@@ -322,7 +380,7 @@ void CfgDlg::WxButton2Click(wxCommandEvent& event)
 
 void CfgDlg::SaveSet()
 {
-    if (!EditMode) return;
+//    if (!EditMode) return;
     
     sprintf(CFG->Device,"%s",UnicodeToStringReturn((wchar_t *)((const wchar_t *)WxEdit1->GetValue().wc_str(wxConvLibc))));
     sprintf(CFG->Name,"%s",UnicodeToStringReturn((wchar_t *)((const wchar_t *)WxEdit2->GetValue().wc_str(wxConvLibc))));
@@ -344,6 +402,13 @@ void CfgDlg::SaveSet()
     } else {
         sprintf(CFG->GetOnlineInfo,"no");
     }
+    
+    if (WxEdit6->GetLabel()!=WxEdit4->GetLabel()) {
+        sprintf(CFG->Features,"%s",WxEdit6->GetLabel());
+    } else {
+        CFG->Features[0] = 0;
+    }
+    sprintf(CFG->Active,"yes");
     s->SaveCfg(Number+1,CFG);
     Number = WxComboBox3->GetCurrentSelection();
     WxStaticText6->SetLabel(CFG->FileName);
@@ -396,6 +461,8 @@ void CfgDlg::WxComboBox3Selected(wxCommandEvent& event )
     SaveSet();
     SelectSet();
     Number = WxComboBox3->GetCurrentSelection();
+    SelectSet();
+    SaveSet();
 }
 
 /*
