@@ -24,7 +24,7 @@
 #endif
 
 #include "../cfg/config.h"
-#include "../common/service/gsmdata.h"
+#include "../common/service/smsmms/gsmmsg.h"
 #include "../common/service/gsmmisc.h"
 #include "../common/service/backup/gsmback.h"
 #include "../common/gsmstate.h"
@@ -37,6 +37,7 @@
 #include <wx/listctrl.h>
 #include <wx/mediactrl.h>
 #include <wx/textctrl.h>
+#include <wx/listbox.h>
 #include <wx/button.h>
 #include <wx/combobox.h>
 #include <wx/panel.h>
@@ -55,7 +56,7 @@ class MMSFrm : public wxMDIChildFrame
 		DECLARE_EVENT_TABLE();
 		
 	public:
-		MMSFrm(MainFrm *parent2, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name, GSM_File *File2, GSM_MMSDecodedFile *Decoded2);
+		MMSFrm(MainFrm *parent2, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style, const wxString& name, GSM_File *File2, GSM_SMSMMSDecodedEntry *Decoded2);
 		virtual ~MMSFrm();
 		void WxComboBox1Selected(wxCommandEvent& event );
 		void WxMediaCtrl1MediaLoaded(wxMediaEvent& event);
@@ -73,6 +74,7 @@ class MMSFrm : public wxMDIChildFrame
 		wxMediaCtrl *WxMediaCtrl1;
 		wxTextCtrl *WxMemo1;
 		wxBoxSizer *WxBoxSizer3;
+		wxListBox *WxListBox1;
 		wxButton *WxButton1;
 		wxComboBox *WxComboBox1;
 		wxPanel *WxPanel1;
@@ -94,6 +96,7 @@ class MMSFrm : public wxMDIChildFrame
 			ID_WXNOTEBOOKPAGE2 = 1008,
 			ID_WXMEDIACTRL1 = 1031,
 			ID_WXMEMO1 = 1028,
+			ID_WXLISTBOX1 = 1032,
 			ID_WXBUTTON1 = 1027,
 			ID_WXCOMBOBOX1 = 1026,
 			ID_WXPANEL1 = 1018,
@@ -105,7 +108,7 @@ class MMSFrm : public wxMDIChildFrame
 
 	private:
         GSM_File                *File;
-    	GSM_MMSDecodedFile      *Decoded;
+    	GSM_SMSMMSDecodedEntry  *Decoded;
 
 		void OnClose(wxCloseEvent& event);
 		void CreateGUIControls();
