@@ -33,6 +33,7 @@
 //Header Include Start and Header Include End.
 //wxDev-C++ designer will remove them. Add custom headers after the block.
 ////Header Include Start
+#include <wx/dirdlg.h>
 #include <wx/menu.h>
 #include <wx/checkbox.h>
 #include <wx/calctrl.h>
@@ -74,7 +75,9 @@ class PhoneFrm : public wxMDIChildFrame
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
+		wxDirDialog *WxDirDialog1;
 		wxMenu *MMSSingleUpWxPopupMenu;
+		wxMenu *FilesMultipleWxPopupMenu;
 		wxMenu *SMSSingleUpWxPopupMenu;
 		wxListCtrl *JavaDownWxListCtrl;
 		wxGridSizer *WxGridSizer16;
@@ -233,6 +236,8 @@ class PhoneFrm : public wxMDIChildFrame
 			////GUI Enum Control ID Start
 			ID_MNU_SAVETOFILE_1104 = 1104,
 			
+			ID_MNU_READ_1227 = 1227,
+			
 			ID_MNU_FORWARD_1095 = 1095,
 			ID_MNU_SENDNEWSMSTOSMSNUMBERS_1144 = 1144,
 			
@@ -405,6 +410,8 @@ public:
 		void SMSFilesWxComboBoxSelected(wxCommandEvent& event );
 		void SMSWxMediaCtrlMediaLoaded(wxMediaEvent& event);
 		void SMSSaveWxButtonClick(wxCommandEvent& event);
+		void FilesWxListCtrlRightClick(wxListEvent& event);
+	void Mnuread1227Click(wxCommandEvent& event);
 private:
         GSM_StateMachine                    *s;
         GSM_Backup                          *Backup;
@@ -453,6 +460,7 @@ private:
         BOOLEAN ReadOneFile(GSM_File *File);
         bool UploadFile(GSM_File *File);
         void AddJava(BOOLEAN Game);
+        void SaveAllFiles();        
 		
         BOOLEAN GetPbkMemories();
         void DisplayPBK(GSM_MemoryType Mem, long *PbkNum,long *ReceivedSec,long *DialledSec);
