@@ -25,10 +25,11 @@
 //Header Include Start and Header Include End.
 //wxDev-C++ designer will remove them. Add custom headers after the block.
 ////Header Include Start
-#include <wx/combobox.h>
-#include <wx/stattext.h>
-#include <wx/listctrl.h>
 #include <wx/button.h>
+#include <wx/choice.h>
+#include <wx/listctrl.h>
+#include <wx/stattext.h>
+#include <wx/combobox.h>
 #include <wx/textctrl.h>
 #include <wx/checkbox.h>
 #include <wx/statbox.h>
@@ -59,12 +60,9 @@ class SMSEditorDlg : public wxDialog
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
-		wxButton *AddOriginalWxButton;
-		wxTextCtrl *WxMemo3;
-		wxStaticBox *WxStaticBox4;
+		wxCheckBox *ReplyWxCheckBox;
 		wxButton *SendWxButton;
 		wxButton *CancelWxButton;
-		wxCheckBox *ReplyWxCheckBox;
 		wxComboBox *ValidityWxComboBox;
 		wxStaticText *WxStaticText1;
 		wxCheckBox *ReportWxCheckBox;
@@ -79,6 +77,36 @@ class SMSEditorDlg : public wxDialog
 		wxButton *NewRecipientAddWxButton;
 		wxStaticBox *WxStaticBox5;
 		wxPanel *WxNoteBookPage3;
+		wxStaticText *WxStaticText10;
+		wxChoice *WxChoice4;
+		wxChoice *WxChoice3;
+		wxStaticText *WxStaticText7;
+		wxChoice *WxChoice2;
+		wxStaticText *WxStaticText6;
+		wxStaticBox *WxStaticBox11;
+		wxStaticText *WxStaticText5;
+		wxChoice *WxChoice1;
+		wxStaticBox *WxStaticBox10;
+		wxStaticBox *WxStaticBox9;
+		wxStaticBox *WxStaticBox8;
+		wxPanel *WxNoteBookPage7;
+		wxTextCtrl *WxEdit2;
+		wxTextCtrl *WxEdit1;
+		wxStaticText *WxStaticText9;
+		wxStaticText *WxStaticText8;
+		wxPanel *WxNoteBookPage6;
+		wxComboBox *WxComboBox3;
+		wxStaticText *WxStaticText4;
+		wxListCtrl *WxListCtrl2;
+		wxPanel *WxNoteBookPage5;
+		wxListCtrl *WxListCtrl1;
+		wxComboBox *WxComboBox2;
+		wxStaticText *WxStaticText3;
+		wxPanel *WxNoteBookPage4;
+		wxComboBox *WxComboBox4;
+		wxCheckBox *WxCheckBox4;
+		wxComboBox *WxComboBox1;
+		wxCheckBox *WxCheckBox1;
 		wxTextCtrl *TextSMSPreviewWxMemo;
 		wxTextCtrl *TextSMSWxMemo;
 		wxCheckBox *TextSMSClassWxCheckBox;
@@ -103,6 +131,18 @@ class SMSEditorDlg : public wxDialog
 		void TextSMSUnicodeWxCheckBoxClick(wxCommandEvent& event);
 		void NewRecipientAddWxButtonClick(wxCommandEvent& event);
 		void NewRecipientWxEditUpdated(wxCommandEvent& event);
+		void TextSMSClassWxCheckBoxClick(wxCommandEvent& event);
+		void WxCheckBox1Click1(wxCommandEvent& event);
+		void WxComboBox1Updated(wxCommandEvent& event );
+		void WxChoice1Selected(wxCommandEvent& event );
+		void WxChoice2Selected(wxCommandEvent& event );
+		void WxChoice3Selected(wxCommandEvent& event );
+		void WxChoice4Selected(wxCommandEvent& event );
+		void WxEdit1Updated1(wxCommandEvent& event);
+		void WxEdit2Updated(wxCommandEvent& event);
+		void WxComboBox4Updated(wxCommandEvent& event );
+		void WxCheckBox4Click(wxCommandEvent& event);
+		void ReplyWxCheckBoxClick(wxCommandEvent& event);
 		
 	private:
 		//Note: if you receive any error with these enum IDs, then you need to
@@ -112,12 +152,9 @@ class SMSEditorDlg : public wxDialog
 		enum
 		{
 			////GUI Enum Control ID Start
-			ID_ADDORIGINALWXBUTTON = 1037,
-			ID_WXMEMO3 = 1036,
-			ID_WXSTATICBOX4 = 1035,
+			ID_REPLYWXCHECKBOX = 1077,
 			ID_SENDWXBUTTON = 1018,
 			ID_CANCELWXBUTTON = 1007,
-			ID_REPLYWXCHECKBOX = 1040,
 			ID_VALIDITYWXCOMBOBOX = 1039,
 			ID_WXSTATICTEXT1 = 1038,
 			ID_REPORTWXCHECKBOX = 1034,
@@ -132,6 +169,36 @@ class SMSEditorDlg : public wxDialog
 			ID_NEWRECIPIENTADDWXBUTTON = 1023,
 			ID_WXSTATICBOX5 = 1022,
 			ID_WXNOTEBOOKPAGE3 = 1017,
+			ID_WXSTATICTEXT10 = 1073,
+			ID_WXCHOICE4 = 1068,
+			ID_WXCHOICE3 = 1067,
+			ID_WXSTATICTEXT7 = 1066,
+			ID_WXCHOICE2 = 1064,
+			ID_WXSTATICTEXT6 = 1063,
+			ID_WXSTATICBOX11 = 1062,
+			ID_WXSTATICTEXT5 = 1061,
+			ID_WXCHOICE1 = 1060,
+			ID_WXSTATICBOX10 = 1057,
+			ID_WXSTATICBOX9 = 1054,
+			ID_WXSTATICBOX8 = 1053,
+			ID_WXNOTEBOOKPAGE7 = 1052,
+			ID_WXEDIT2 = 1072,
+			ID_WXEDIT1 = 1071,
+			ID_WXSTATICTEXT9 = 1070,
+			ID_WXSTATICTEXT8 = 1069,
+			ID_WXNOTEBOOKPAGE6 = 1045,
+			ID_WXCOMBOBOX3 = 1051,
+			ID_WXSTATICTEXT4 = 1050,
+			ID_WXLISTCTRL2 = 1049,
+			ID_WXNOTEBOOKPAGE5 = 1044,
+			ID_WXLISTCTRL1 = 1048,
+			ID_WXCOMBOBOX2 = 1047,
+			ID_WXSTATICTEXT3 = 1046,
+			ID_WXNOTEBOOKPAGE4 = 1043,
+			ID_WXCOMBOBOX4 = 1075,
+			ID_WXCHECKBOX4 = 1074,
+			ID_WXCOMBOBOX1 = 1042,
+			ID_WXCHECKBOX1 = 1041,
 			ID_TEXTSMSPREVIEWWXMEMO = 1014,
 			ID_TEXTSMSWXMEMO = 1013,
 			ID_TEXTSMSCLASSWXCHECKBOX = 1012,
@@ -152,10 +219,13 @@ class SMSEditorDlg : public wxDialog
 		void OnClose(wxCloseEvent& event);
 		void CreateGUIControls();
         void SetInfo();		
+void SMSEditorDlg::Indicators();        
+void SMSEditorDlg::WAPBookmark();
 		
 		GSM_SMSList       *List;
 		GSM_StateMachine  *s;
 		long              num;
+		BOOLEAN start;
 };
 
 #endif
