@@ -124,33 +124,33 @@ int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *Lis
         Found = false;
         AddNum=false;
         switch (SubDecoded->Type) {
-        case MMS_Address_Phone_Source:
+        case MSG_MMSSMS_Address_Phone_Source:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "From (phone)", 0); Found = true;
             AddNum = true;
             break;
-    	case MMS_Address_Unknown_Source:
+    	case MSG_MMS_Address_Unknown_Source:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "From", 0); Found = true;
             AddNum = true;
             break;
-        case MMS_Address_Phone_Destination:
+        case MSG_MMS_Address_Phone_Destination:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "To (phone)", 0); Found = true;
             break;
-        case MMS_Address_Unknown_Destination:
+        case MSG_MMS_Address_Unknown_Destination:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "To", 0); Found = true;
             break;
-        case MMS_Address_Phone_CC:
+        case MSG_MMS_Address_Phone_CC:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "CC (phone)", 0); Found = true;
             break;
-        case MMS_Address_Unknown_CC:
+        case MSG_MMS_Address_Unknown_CC:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "CC", 0); Found = true;
             break;
-        case MMS_Address_Phone_BCC:
+        case MSG_MMS_Address_Phone_BCC:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "BCC (phone)", 0); Found = true;
             break;
-        case MMS_Address_Unknown_BCC:
+        case MSG_MMS_Address_Unknown_BCC:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "BCC", 0); Found = true;
             break;
-        case MMS_Unknown:
+        case MSG_Unknown:
             if (List != NULL) tmp = List->InsertItem(EntryNum++, "<Unknown content>", 0); Found = true;
             break;
         }
@@ -166,37 +166,37 @@ int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *Lis
         }
         if (List!=NULL) {
             switch (SubDecoded->Type) {
-            case MMS_Text_TransactionID:
+            case MSG_MMS_Text_TransactionID:
                 tmp = List->InsertItem(EntryNum++, "Transaction ID", 0); Found = TRUE;
                 break;
-            case MMS_Text_Subject:
+            case MSG_MMS_Text_Subject:
                 tmp = List->InsertItem(EntryNum++, "Subject", 0); Found = TRUE;
                 break;
-            case MMS_Text_ContentLocation:
+            case MSG_MMS_Text_ContentLocation:
                 tmp = List->InsertItem(EntryNum++, "Content location", 0); Found = TRUE;
                 break;
-            case MMS_Text_ContentType:
+            case MSG_MMS_Text_ContentType:
                 tmp = List->InsertItem(EntryNum++, "Content type", 0); Found = TRUE;
                 break;
-            case MMS_Text_MessageType:
+            case MSG_MMS_Text_MessageType:
                 tmp = List->InsertItem(EntryNum++, "Message type", 0); Found = TRUE;
                 break;
-            case MMS_Text_MessageID:
+            case MSG_MMS_Text_MessageID:
                 tmp = List->InsertItem(EntryNum++, "Message ID", 0); Found = TRUE;
                 break;
-            case MMS_Text_MessageClass:
+            case MSG_MMS_Text_MessageClass:
                 tmp = List->InsertItem(EntryNum++, "Message class", 0); Found = TRUE;
                 break;
-            case MMS_Text_Priority:
+            case MSG_MMS_Text_Priority:
                 tmp = List->InsertItem(EntryNum++, "Priority", 0); Found = TRUE;
                 break;
-            case MMS_Text_Version:
+            case MSG_MMS_Text_Version:
                 tmp = List->InsertItem(EntryNum++, "MMS version", 0); Found = TRUE;
                 break;
-            case MMS_Text_Response_Status:
+            case MSG_MMS_Text_Response_Status:
                 tmp = List->InsertItem(EntryNum++, "Response status", 0); Found = TRUE;
                 break;
-            case MMS_Text_Status:
+            case MSG_MMS_Text_Status:
                 tmp = List->InsertItem(EntryNum++, "Status", 0); Found = TRUE;
                 break;
             }
@@ -205,13 +205,13 @@ int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *Lis
                 continue;
             }
             switch (SubDecoded->Type) {
-            case MMS_Bool_Report:
+            case MSG_MMS_Bool_Report:
                 tmp = List->InsertItem(EntryNum++, "Delivery report", 0); Found = TRUE;
                 break;
-            case MMS_Bool_Read_Reply:
+            case MSG_MMS_Bool_Read_Reply:
                 tmp = List->InsertItem(EntryNum++, "Read reply", 0); Found = TRUE;
                 break;
-            case MMS_Bool_Report_Allowed:
+            case MSG_MMS_Bool_Report_Allowed:
                 tmp = List->InsertItem(EntryNum++, "Report allowed", 0); Found = TRUE;
                 break;
             }
@@ -225,20 +225,20 @@ int ViewMMSFile(GSM_File *File, GSM_SMSMMSDecodedEntry *Decoded, wxListCtrl *Lis
             }
         }
         switch (SubDecoded->Type) {
-        case MMS_DT_DateTime:
+        case MSG_MMS_DT_DateTime:
             if (List!=NULL) {
                 tmp = List->InsertItem(EntryNum++, "Sent", 0);
                 PrintDT(&SubDecoded->DT, buff);
                 List->SetItem(tmp, 1, buff);
             }
             break;
-    	case MMS_DT_Expiry:
+    	case MSG_MMS_DT_Expiry:
             if (List!=NULL) {
                 tmp = List->InsertItem(EntryNum++, "Expiry", 0);
                 List->SetItem(tmp, 1, SubDecoded->Text.data());
             }
             break;
-        case MMS_File:
+        case MSG_MMSSMS_File:
             if (List!=NULL) {
                 tmp = List->InsertItem(EntryNum++, "File", 0);
                 tmp = List->InsertItem(EntryNum++, "  Content type", 0);
@@ -298,7 +298,7 @@ void MMSSelect(int Num, GSM_SMSMMSDecodedEntry *Decoded, wxMediaCtrl *MediaCtrl1
 
     SubDecoded = NULL;
     while (Decoded->GetNext(&SubDecoded)) {
-        if (SubDecoded->Type !=  MMS_File) continue;
+        if (SubDecoded->Type !=  MSG_MMSSMS_File) continue;
         num5++;
         if (num5-1!=Num) continue;
 
@@ -377,7 +377,7 @@ void SaveMMSFile(GSM_SMSMMSDecodedEntry *Decoded, wxFileDialog *WxSaveFileDialog
 
     SubDecoded = NULL;
     while (Decoded->GetNext(&SubDecoded)) {
-        if (SubDecoded->Type !=  MMS_File) continue;
+        if (SubDecoded->Type !=  MSG_MMSSMS_File) continue;
         num5++;
         if (num5-1!=Num) continue;
 
